@@ -1,4 +1,4 @@
-from nextnanopy.outputs import DataFile
+from nextnanopy.outputs import DataFile, DataFolder
 from nextnanopy.commands import execute
 from nextnanopy.inputs import InputFile, Sweep
 from nextnanopy.defaults import NNConfig
