@@ -509,18 +509,29 @@ class Sweep(InputFile):
         self.sweep_output_directory = None
         self.input_files = []
 
-    def save_sweep(self, delete_old_files = True):
+    def save_sweep(self, delete_old_files = True, round_decimal = 8):
+        """
+
+        Parameters
+        ----------
+        delete_old_files: if True, deletes files created in previous sweeps
+        round: number of digits to round in the output folder names
+
+        Returns
+        -------
+        None
+        """
         if delete_old_files == True:
             for inputfile in self.input_files:
                 inputfile.remove()
         self.input_files = []
-        self.create_input_files()
+        self.create_input_files(round_decimal)
 
     def prepare_output(self, overwrite = False):
         self.sweep_output_directory = self.mk_dir(overwrite=overwrite)
         self.create_info()
 
-    def create_input_files(self):
+    def create_input_files(self, round_decimal):
         iteration_combinations = list(itertools.product(*self.var_sweep.values()))
         filename_path, filename_extension = os.path.splitext(self.fullpath)
         for combination in iteration_combinations:
@@ -528,7 +539,11 @@ class Sweep(InputFile):
             inputfile = InputFile(fullpath = self.fullpath, configpath = self.configpath)
             for var_name, var_value in zip(self.var_sweep.keys(), combination):
                 inputfile.set_variable(var_name, var_value, comment='THIS VARIABLE IS UNDER SWEEP')
-                filename_end += '{}_{}_'.format(var_name, var_value)
+                if isinstance(var_value,str):
+                    var_value_string = var_value
+                else:
+                    var_value_string = round(var_value, round_decimal)
+                filename_end += '{}_{}_'.format(var_name, var_value_string)
             inputfile.save(filename_path + filename_end + filename_extension, overwrite = True)
             self.input_files.append(inputfile)
 
@@ -545,7 +560,8 @@ class Sweep(InputFile):
             if True, the output overwrites the old output data. If False, execution will create a new output folder
             (with the unique name, created by adding an integer to the foldername). Default is False.
         show_log : bool, optional
-            if True, the simulation log is displayed in the console, while False suppresses the log. Default is True.
+            if True, the simulation log is displayed in the console. If False, the count of current simulation is displayed without log. 
+            Default is True.
             Note that the log file is always saved in the output folders regardless of this option.
         convergenceCheck : bool, optional
             if True, nextnanopy scans the log file of the simulation performed and check whether the solution has converged. 
@@ -557,7 +573,9 @@ class Sweep(InputFile):
         output_directory = self.sweep_output_directory
         if not self.input_files:
             warnings.warn('Nothing was executed in sweep! Input files to execute were not created.')
-        for inputfile in self.input_files:
+        for i, inputfile in enumerate(self.input_files):
+            if not show_log:
+                print(f"\nExecuting simulations [{i+1}/{len(self.input_files)}]...")
             inputfile.execute(outputdirectory = output_directory, show_log = show_log, convergenceCheck = convergenceCheck)
             if delete_input_files:
                 inputfile.remove()
