@@ -1,9 +1,11 @@
+from nextnanopy.utils.datasets import InputVariable
 from nextnanopy.utils.formatting import str_to_path, _path, pattern_in_file, is_variable, parse_variable, \
     generate_command, pattern_in_text
 from collections import OrderedDict
 
+
 fmt = {
-    'var_char': 'NOT DEFINED',
+    'var_char': '$',
     'com_char': '<!--',
     'input_pattern': '<Simulation',
 }
@@ -49,9 +51,14 @@ def is_negf_variable(text):
     return is_variable(text, var_char=fmt['var_char'])
 
 
-def parse_negf_variable(text):
-    return parse_variable(text, var_char=fmt['var_char'], com_char=fmt['com_char'])
+#def parse_negf_variable(text):
+#    return parse_variable(text, var_char=fmt['var_char'], com_char=fmt['com_char'])
 
+def parse_negf_variable_name(text):
+    if text.startswith(fmt['var_char']):
+        return text[1:]
+    else:
+        raise ValueError(f"variable name in NEGF should start with {fmt['var_char']}")
 
 def is_negf_input_file(fullpath):
     return pattern_in_file(fullpath, fmt['input_pattern'])
@@ -59,3 +66,14 @@ def is_negf_input_file(fullpath):
 
 def is_negf_input_text(text):
     return pattern_in_text(text, fmt['input_pattern'])
+
+
+class InputVariable_NEGF(InputVariable):
+    var_char = fmt['var_char']
+
+    @property
+    def text(self):
+        t = f'{self.var_char}{self.name} = {self.value} {self.unit}'
+        if self.comment:
+            t = f'{t} Comment: {self.comment}'
+        return t
