@@ -2,6 +2,7 @@ import os
 from itertools import islice
 import numpy as np
 import struct
+import warnings
 
 from nextnanopy.utils.datasets import Variable, Coord
 from nextnanopy.utils.mycollections import DictList
@@ -11,8 +12,191 @@ from nextnanopy import defaults
 
 import pyvista as pv
 
+
 _msgs = defaults.messages['load_output']
 load_message = lambda method: message_decorator(method, init_msg=_msgs[0], end_msg=_msgs[1])
+def displayname(data):
+    """
+    Parameters
+    ----------
+    data: DataFolder or filepath
+    Returns
+    -------
+    str
+    formatting filenames and folder names in datafolder to display DataFolder in tree structure
+    """
+    if isinstance(data, DataFolder):
+        return os.path.basename(data.fullpath)+r'/'
+    else:
+        return  os.path.basename(data)
+
+class DataFolder(object):
+    """
+        This class stores information about output directory.
+        The stored data contains files (.files) and folders (.folders)
+        Navigation between folders could be done in 3 ways:
+            1. DataFolder.folders['folder_name']
+            2. DataFolder.go_to('subfolder1', 'subfolder2', 'subfolder3')
+            3. DataFolder.subfolder1.subfolder2.subfolder3
+        For each method see details below.
+
+        The initialization of the class will execute load and create_navigation methods.
+
+
+        Parameters:
+        ----------------
+        fullpath: str
+            path to a file
+
+
+
+        Attributes:
+        ----------------
+        fullpath: str
+        path to a file
+
+        folders: DictList
+            subfolders of the DataFolder,
+            keys: str
+                names of subfolders
+            values: DataFolder
+                DataFolder objects of subfolders
+
+        files: list
+            paths to files in folder
+
+
+        Methods:
+        --------------
+        load():
+            load a DataFolder
+
+        create_navigation:
+            creates attributes for navigation like DataFolder.subfolder1.subfolder2.subfolder3
+            if name of subfolder corresponds to existed attribute of DataFolder class, attribute will not be created!
+            if name of subfolder constis spaces, dots or specials charecters, attribute will be created, but navigation
+            to whis subfolder will not work  - attribute error.
+
+        find(template, deep = False):
+            searches for a files which names contain template.
+            template shoud be string.
+            if deep = True, searches in subfolders as well.
+
+            return: list of files
+
+        go_to(*args):
+            goes to the location
+            DataFolder_path\\arg1\\arg2\\arg3...
+
+            if location is a file:
+                return filepath
+            if location is a folder:
+                return DataFolder(location)
+
+        filenames()
+            return filenames of files in folder
+        """
+    def __init__(self, fullpath):
+        if not os.path.isdir(fullpath):
+            raise ValueError(f"{fullpath} is not a directory")
+        self.fullpath = fullpath
+        self.files = []
+        self.folders = DictList()
+        self.load()
+        self.create_navigation()
+
+    def load(self):
+        list_of_nodes = os.listdir(self.fullpath)
+        for node in list_of_nodes:
+            node_path = os.path.join(self.fullpath, node)
+            if os.path.isdir(node_path):
+                new_folder = DataFolder(node_path)
+                self.folders[node] = new_folder
+            else:
+                self.files.append(node_path)
+
+    def create_navigation(self):
+        check_list = dir(self)
+        for key, folder in self.folders.items():
+            if key in check_list:
+                warnings.warn(f"foldername '{key}' is not availabel for attribute navigation."
+                              " Please, use DataFolder.go_to()")
+            else:
+                setattr(self, key, folder)
+
+    def find(self, template, deep=False):
+        list_of_files = [file for file in self.files if template in os.path.basename(file)]
+        if not deep:
+            return list_of_files
+        if not self.folders:
+            return list_of_files
+        else:
+            for folder in self.folders:
+                list_of_files += folder.find(template=template, deep=deep)
+            return list_of_files
+
+
+    def file(self, filename):
+        matched_files = self.find(template = filename, deep = False)
+        if not matched_files:
+            raise ValueError(f'No file with filename {filename} in directory {self.fullpath}')
+        elif len(matched_files) == 1:
+            return matched_files[0]
+        else:
+            warnings.warn(f"More than one file match '{filename}' name match in directory {self.fullpath}. First match returned.")
+            return matched_files[0]
+
+    def go_to(self, *args):
+        path = os.path.join(self.fullpath, *args)
+        if os.path.isdir(path):
+            data = DataFolder(path)
+        elif os.path.isfile(path):
+            data = path
+        else:
+            raise ValueError(f'No such file or directory {path}')
+        return data
+
+    def filenames(self):
+        return [os.path.basename(file) for file in self.files]
+
+    def __repr__(self):
+        out = list()
+        out.append(f'{self.__class__.__name__}')
+        out.append(f'fullpath: {self.fullpath}')
+        out.append(f'Folders: {len(self.folders)}')
+        for key in self.folders.keys():
+            out.append(key)
+        out.append('Files:')
+        out.append(str(self.filenames()))
+        out = '\n'.join(out)
+        return out
+
+
+    def make_tree(self, level = 0, result = None, with_files = True, deep = True):
+        if not result:
+            result = []
+        result.insert(level,level*'    '+ displayname(self))
+        if with_files:
+            for file in reversed(self.files):
+                result.insert(level+1,(level+1)*'    '+displayname(file))
+        level = level + 1
+        for i in reversed(range(len(self.folders))):
+            folder = self.folders[i]
+            if deep:
+                result = folder.make_tree(level, result = result, with_files = with_files)
+            else:
+                result.insert(level, level * '    ' + displayname(folder))
+        return result
+
+
+    def show_tree(self, with_files = True, deep = True):
+        tree_list = self.make_tree(with_files = with_files, deep = deep)
+        print('\n'.join(tree_list))
+
+
+
+
+
 
 
 class Output(object):
@@ -219,6 +403,71 @@ class DataFile(DataFileTemplate):
         loader = Dati
         return loader
 
+    def plot(self, legend = False, y_axis_name = '', subplots = False):
+        import matplotlib.pyplot as plt
+        if len(self.coords) == 0:
+            fig, ax = plt.subplots()
+            if len(self.variables)>1:
+                plot_coord =self.variables[0]
+                #plot_var = self.variables[1:]
+                #for var in plot_var:
+                for i in range(1, len(self.variables)-1):
+                    var = self.variables[i]
+                    ax.plot(plot_coord.value, var.value, label=var.name)
+                ax.set_xlabel(f'{plot_coord.name}[{plot_coord.unit}]')
+            else:
+                for var in self.variables:
+                    ax.plot(var.value, label=var.name)
+            ax.set_ylabel(f'{y_axis_name}[{var.unit}]')
+        elif len(self.coords) == 1:
+            fig, ax = plt.subplots()
+            x_coord = self.coords[0]
+            x_label_name = x_coord.name
+            x_label_unit = x_coord.unit
+            x_value = x_coord.value
+            ax.set_xlabel(f'{x_label_name}[{x_label_unit}]')
+            for var in self.variables:
+                ax.plot(x_value, var.value, label = var.name)
+            ax.set_ylabel(f'{y_axis_name}[{var.unit}]')
+            if legend:
+                plt.legend()
+        elif len(self.coords) == 2:
+            x = self.coords[0]
+            y = self.coords[1]
+            number_of_var = len(self.variables)
+            if number_of_var <2:
+                fig, ax = plt.subplots()
+                ax.set_xlabel(f'{x.name}[{x.unit}]')
+                ax.set_ylabel(f'{y.name}[{y.unit}]')
+                var = self.variables[0]
+                im = ax.pcolormesh(x.value, y.value, var.value, shading='auto', label=f'{var.name}[{var.unit}]')
+                ax.set_title(f'{var.name}[{var.unit}]')
+                fig.colorbar(im, ax = ax)
+            else:
+                if subplots:
+                    fig, ax = plt.subplots(len(self.variables))
+                    for i in range(len(self.variables)):
+                        var = self.variables[i]
+                        im = ax[i].pcolormesh(x.value, y.value, var.value, shading='auto', label=f'{var.name}[{var.unit}]')
+                        ax[i].set_xlabel(f'{x.name}[{x.unit}]')
+                        ax[i].set_ylabel(f'{y.name}[{y.unit}]')
+                        ax[i].set_title(f'{var.name}[{var.unit}]')
+                        fig.colorbar(im, ax=ax[i])
+                else:
+                    for i in range(len(self.variables)):
+                        fig, ax = plt.subplots()
+                        var = self.variables[i]
+                        im = ax.pcolormesh(x.value, y.value, var.value, shading='auto', label=f'{var.name}[{var.unit}]')
+                        ax.set_xlabel(f'{x.name}[{x.unit}]')
+                        ax.set_ylabel(f'{y.name}[{y.unit}]')
+                        ax.set_title(f'{var.name}[{var.unit}]')
+                        fig.colorbar(im, ax=ax)
+        else:
+            raise NotImplementedError('Preview plot feature is implemented only for datafiles with 2 or less coordinates')
+        return fig,ax
+
+
+
 
 class AvsAscii(Output):
     def __init__(self, fullpath):
